@@ -7,8 +7,10 @@
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygobject.h>
 
-void pyui_register_classes (PyObject *d);
+#include <libgnomeui/libgnomeui.h>
 
+void pyui_register_classes (PyObject *d);
+void pyui_add_constants(PyObject *module, const gchar *strip_prefix);
 extern PyMethodDef pyui_functions[];
 
 DL_EXPORT(void)
@@ -23,6 +25,8 @@ initui (void)
 	
     pyui_register_classes (d);
     pyui_add_constants (m, "GNOME_");
+
+    gnome_program_module_register(LIBGNOMEUI_MODULE);
 	
     if (PyErr_Occurred ()) {
 	Py_FatalError ("can't initialise module gnome.ui");
